bet package
===========

Subpackages
-----------

.. toctree::

    bet.calculateP
    bet.postProcess
    bet.sampling
    bet.sensitivity

Submodules
----------

bet.Comm module
---------------

.. automodule:: bet.Comm
    :members:
    :undoc-members:
    :show-inheritance:

bet.sample module
-----------------

.. automodule:: bet.sample
    :members:
    :undoc-members:
    :show-inheritance:

bet.surrogates module
---------------------

.. automodule:: bet.surrogates
    :members:
    :undoc-members:
    :show-inheritance:

bet.util module
---------------

.. automodule:: bet.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bet
    :members:
    :undoc-members:
    :show-inheritance:
